==> nextcloud-16.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/eu.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galeria",
    "There was a problem reading files from this album" : "Arazoren bat egon da album horretako fitxategiak irakurtzean",
    "Aborting preview. Could not find the file" : "Aurrebista bertan behera utzi da. Ezin da fitxategia topatu",
    "Could not move \"{file}\", target exists" : "Ezin da \"{file}\" mugitu, helburuan existitzen da jadanik",
    "Could not move \"{file}\"" : "Ezin da mugitu \"{file}\"",
    "No compatible server found at {remote}" : "Zerbitzari bateraezina topatu da {remote} ",
    "Invalid server url" : "Baliogabeko zerbitzariaren url-a",
    "Could not load the description" : "Ezin da deskribapena kargatu",
    "Could not load the description: " : "Ezin da deskribapena kargatu:",
    "Copyright" : "Copyright",
    "Could not load the copyright notice: " : "Ezin da copyright oharra kargatu:",
    "Copyright notice" : "Copyright oharra",
    "Link to copyright document" : "Copyright dokumentura lotura",
    "This application may not work properly on your browser." : "Aplikazio hau agian ez du ondo funtzionatzen zure nabigatzailean",
    "For an improved experience, please install one of the following alternatives" : "Esperientzia hobegoa izateko, instala ezazu mesedez aukera hauetako bat",
    "Your browser is not supported!" : "Zure nabigatzaileak ez du euskarririk",
    "please install one of the following alternatives" : "Instala ezazu mesedez aukera hauetako bat",
    "Album cannot be shown" : "Albuma ezin da ikusi",
    "No media files found" : "Ez dago media fitxategirik",
    "Upload pictures in the Files app to display them here" : "Fitxategiak app-an irudiak igo hemen ager daitezen",
    "Upload new files via drag and drop or by using the [+] button above" : "Fitxategi berriak gehitu arratatu eta askatuz edo [+] botoia erabiliz",
    "Configuration error" : "Konfigurazio errorea",
    "Hide Album" : "Ezkutatu albuma",
    "Could not hide album" : "Ezin da ezkutatu albuma",
    "Error loading slideshow template" : "Errorea aurkezpen txantiloia kargatzean",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Errorea!</strong> Ezin da fitxategiaren aurrebista sortu.<br> Hurrengo gardenkira joan mesedez, irudi hau borratzen dugun bitartean",
    "Next" : "Hurrengoa",
    "Play" : "Erreproduzitu",
    "Pause" : "Pausarazi",
    "Previous" : "Aurrekoa",
    "Close" : "Itxi",
    "Download" : "Deskargatu",
    "Toggle background" : "Atzeko planoa aldatu",
    "Delete" : "Ezabatu",
    "Share" : "Elkarbanatu",
    "Could not create file \"{file}\" because it already exists" : "Ezin izan da \"{file}\" fitxategia sortu, dagoeneko existitzen delako",
    "Could not create file \"{file}\"" : "Ezin izan da \"{file}\" fitxategia sortu",
    "\"{name}\" is an invalid file name." : "\"{name}\" ez da fitxategi izen baliogarria.",
    "File name cannot be empty." : "Fitxategi izena ezin da hutsa izan.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" fitxategi mota ez da onartzen",
    "Upload" : "Igo",
    "Error" : "Errorea",
    "Error while sharing" : "Errore bat egon da elkarbanatzean",
    "Error while unsharing" : "Errore bat egon da elkarbanaketa desegitean",
    "Error while changing permissions" : "Errore bat egon da baimenak aldatzean",
    "Shared with you and the group {group} by {owner}" : "{owner}-k zu eta {group} taldearekin elkarbanatuta",
    "Shared with you by {owner}" : "{owner}-k zurekin elkarbanatuta",
    "Share with users or groups …" : "Partekatu taldeen erabiltzaileekin...",
    "Share with users, groups or remote users …" : "Partekatu erabiltzaileekin, taldeekin edo urrutiko erabiltzaileekin...",
    "Share link" : "Elkarbanatu lotura",
    "The public link will expire no later than {days} days after it is created" : "Esteka publikoak iraungi egingo du, askoz jota, sortu eta  {days} egunetara.",
    "Link" : "Esteka",
    "Password protect" : "Babestu pasahitzarekin",
    "Password" : "Pasahitza",
    "Choose a password for the public link" : "Aukeratu pasahitz bat esteka publikorako",
    "Allow editing" : "Baimendu editatzea",
    "Email link to person" : "Postaz bidali lotura ",
    "Send" : "Bidali",
    "Set expiration date" : "Ezarri muga data",
    "Expiration" : "Iraungitzea",
    "Expiration date" : "Muga data",
    "This list is maybe truncated - please refine your search term to see more results." : "Zerrenda hau apurtuta egon daiteke - zure bilaketa birfindu emaitza gehiago eduki ahal izateko",
    "No users or groups found for {search}" : "Ez da erabiltzaile edo talderik topatu {search}-erako",
    "No users found for {search}" : "Ez da erabiltzailerik topatu {search}-erako",
    "An error occurred (\"{message}\"). Please try again" : "Errore bat gertatu da  (\"{message}\"). Saiatu berriro.",
    "An error occurred. Please try again" : "Errore bat gertatu da. Saiatu berriro.",
    "Adding user..." : "Erabiltzailea gehitzen...",
    "group" : "taldea",
    "remote" : "urrunekoa",
    "Resharing is not allowed" : "Berriz elkarbanatzea ez dago baimendua",
    "Error while retrieving shares" : "Partekatuak jasotzean errorea",
    "Unshare" : "Ez elkarbanatu",
    "notify by email" : "jakinarazi eposta bidez",
    "can share" : "elkarbana dezake",
    "can edit" : "editatu dezake",
    "access control" : "sarrera kontrola",
    "create" : "sortu",
    "change" : "aldatu",
    "delete" : "ezabatu",
    "Password protected" : "Pasahitzarekin babestuta",
    "Error unsetting expiration date" : "Errorea izan da muga data kentzean",
    "Error setting expiration date" : "Errore bat egon da muga data ezartzean",
    "Sending…" : "Bidaltzen...",
    "Email sent" : "Eposta bidalia",
    "Warning" : "Abisua",
    "shared by %s" : "%s erabiltzaileak partekatua",
    "Direct link" : "Esteka zuzena",
    "Add to your Nextcloud" : "Gehitu zure Nextcloud-era",
    "Media gallery for Nextcloud" : "Nextcloud multimedia galeria",
    "This share is password-protected" : "Elkarbanatutako hau pasahitzarekin babestuta dago",
    "The password is wrong. Try again." : "Pasahitza ez da egokia. Saiatu berriro.",
    "Cancel upload" : "Ezeztatu igoera",
    "Sort by name" : "Ordenatu izenaren arabera",
    "Sort by date" : "Ordenatu dataren arabera",
    "Album information" : "Albumaren informazioa",
    "File list" : "Fitxategi zerrenda",
    "Sorry, this file could not be found." : "Barkatu fitxategi hau ezin izan da aurkitu",
    "Reasons might be:" : "Arrazoiak hurrengoak litezke:",
    "the wrong file ID was provided" : "Fitxategiaren ID ezegokia eman da",
    "the file was removed" : "fitxategia ezabatua izan da",
    "the file is corrupt" : "fitxategia apurtua dago",
    "the encryption key is missing" : "enkriptazio gakoa falta da",
    "Here is the error message returned by the server: " : "Hona hemen zerbitzariak itzulitako errore mezua: ",
    "For more information, please contact your friendly Nextcloud administrator." : "Informazio gehiagorako, zure lagun Nextcloud administratzailearekin kontaktuan jar zaitez",
    "Sorry, but the server could not fulfill your request." : "Barkatu, baina zerbitzariak ezin du zure eskaera bete",
    "Possible reasons for the problem:" : "Arazoa sor dezaketen arrazoiak: ",
    "a conflicting app was installed" : "arazoak ematen duen app bat instalatu da",
    "a required component is missing or was disconnected" : "beharrezkoa den ezaugarri bat faltan edo deskonektatua dago",
    "the filesystem is not readable" : "fitxategi-sistema ezin da irakurri",
    "Sorry, this link doesn't seem to work anymore." : "Barkatu, ematen du lotura ez duela funtzionatzen.",
    "the item was removed" : "elementua ezabatua izan da",
    "the link has expired" : "lotura iraungi da",
    "sharing is disabled" : "elkarbanatzea ez dago gaituta",
    "For more information, please ask the person who has sent you this link." : "Informazio gehiagorako, eskatu lotura hau bidali dizun pertsonari",
    "Picture view" : "Irudi bistaratzea",
    "New" : "Berria"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/eu.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galeria",
    "There was a problem reading files from this album" : "Arazoren bat egon da album horretako fitxategiak irakurtzean",
    "Aborting preview. Could not find the file" : "Aurrebista bertan behera utzi da. Ezin da fitxategia topatu",
    "Could not move \"{file}\", target exists" : "Ezin da \"{file}\" mugitu, helburuan existitzen da jadanik",
    "Could not move \"{file}\"" : "Ezin da mugitu \"{file}\"",
    "No compatible server found at {remote}" : "Zerbitzari bateraezina topatu da {remote} ",
    "Invalid server url" : "Baliogabeko zerbitzariaren url-a",
    "Could not load the description" : "Ezin da deskribapena kargatu",
    "Could not load the description: " : "Ezin da deskribapena kargatu:",
    "Copyright" : "Copyright",
    "Could not load the copyright notice: " : "Ezin da copyright oharra kargatu:",
    "Copyright notice" : "Copyright oharra",
    "Link to copyright document" : "Copyright dokumentura lotura",
    "This application may not work properly on your browser." : "Aplikazio hau agian ez du ondo funtzionatzen zure nabigatzailean",
    "For an improved experience, please install one of the following alternatives" : "Esperientzia hobegoa izateko, instala ezazu mesedez aukera hauetako bat",
    "Your browser is not supported!" : "Zure nabigatzaileak ez du euskarririk",
    "please install one of the following alternatives" : "Instala ezazu mesedez aukera hauetako bat",
    "Album cannot be shown" : "Albuma ezin da ikusi",
    "No media files found" : "Ez dago media fitxategirik",
    "Upload pictures in the Files app to display them here" : "Fitxategiak app-an irudiak igo hemen ager daitezen",
    "Upload new files via drag and drop or by using the [+] button above" : "Fitxategi berriak gehitu arratatu eta askatuz edo [+] botoia erabiliz",
    "Configuration error" : "Konfigurazio errorea",
    "Hide Album" : "Ezkutatu albuma",
    "Could not hide album" : "Ezin da ezkutatu albuma",
    "Error loading slideshow template" : "Errorea aurkezpen txantiloia kargatzean",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Errorea!</strong> Ezin da fitxategiaren aurrebista sortu.<br> Hurrengo gardenkira joan mesedez, irudi hau borratzen dugun bitartean",
    "Next" : "Hurrengoa",
    "Play" : "Erreproduzitu",
    "Pause" : "Pausarazi",
    "Previous" : "Aurrekoa",
    "Close" : "Itxi",
    "Download" : "Deskargatu",
    "Toggle background" : "Atzeko planoa aldatu",
    "Delete" : "Ezabatu",
    "Share" : "Elkarbanatu",
    "Could not create file \"{file}\" because it already exists" : "Ezin izan da \"{file}\" fitxategia sortu, dagoeneko existitzen delako",
    "Could not create file \"{file}\"" : "Ezin izan da \"{file}\" fitxategia sortu",
    "\"{name}\" is an invalid file name." : "\"{name}\" ez da fitxategi izen baliogarria.",
    "File name cannot be empty." : "Fitxategi izena ezin da hutsa izan.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" fitxategi mota ez da onartzen",
    "Upload" : "Igo",
    "Error" : "Errorea",
    "Error while sharing" : "Errore bat egon da elkarbanatzean",
    "Error while unsharing" : "Errore bat egon da elkarbanaketa desegitean",
    "Error while changing permissions" : "Errore bat egon da baimenak aldatzean",
    "Shared with you and the group {group} by {owner}" : "{owner}-k zu eta {group} taldearekin elkarbanatuta",
    "Shared with you by {owner}" : "{owner}-k zurekin elkarbanatuta",
    "Share with users or groups …" : "Partekatu taldeen erabiltzaileekin...",
    "Share with users, groups or remote users …" : "Partekatu erabiltzaileekin, taldeekin edo urrutiko erabiltzaileekin...",
    "Share link" : "Elkarbanatu lotura",
    "The public link will expire no later than {days} days after it is created" : "Esteka publikoak iraungi egingo du, askoz jota, sortu eta  {days} egunetara.",
    "Link" : "Esteka",
    "Password protect" : "Babestu pasahitzarekin",
    "Password" : "Pasahitza",
    "Choose a password for the public link" : "Aukeratu pasahitz bat esteka publikorako",
    "Allow editing" : "Baimendu editatzea",
    "Email link to person" : "Postaz bidali lotura ",
    "Send" : "Bidali",
    "Set expiration date" : "Ezarri iraungitze-data",
    "Expiration" : "Iraungitzea",
    "Expiration date" : "Iraungitze-data",
    "This list is maybe truncated - please refine your search term to see more results." : "Zerrenda hau apurtuta egon daiteke - zure bilaketa birfindu emaitza gehiago eduki ahal izateko",
    "No users or groups found for {search}" : "Ez da erabiltzaile edo talderik topatu {search}-erako",
    "No users found for {search}" : "Ez da erabiltzailerik topatu {search}-erako",
    "An error occurred (\"{message}\"). Please try again" : "Errore bat gertatu da  (\"{message}\"). Saiatu berriro.",
    "An error occurred. Please try again" : "Errore bat gertatu da. Saiatu berriro.",
    "Adding user..." : "Erabiltzailea gehitzen...",
    "group" : "taldea",
    "remote" : "urrunekoa",
    "Resharing is not allowed" : "Berriz elkarbanatzea ez dago baimendua",
    "Error while retrieving shares" : "Partekatuak jasotzean errorea",
    "Unshare" : "Ez elkarbanatu",
    "notify by email" : "jakinarazi eposta bidez",
    "can share" : "elkarbana dezake",
    "can edit" : "editatu dezake",
    "access control" : "sarrera kontrola",
    "create" : "sortu",
    "change" : "aldatu",
    "delete" : "ezabatu",
    "Password protected" : "Pasahitzarekin babestuta",
    "Error unsetting expiration date" : "Errorea irangitze-data kentzean",
    "Error setting expiration date" : "Errorea iraungitze-data ezartzean",
    "Sending…" : "Bidaltzen...",
    "Email sent" : "Eposta bidalia",
    "Warning" : "Abisua",
    "shared by %s" : "%s erabiltzaileak partekatua",
    "Direct link" : "Esteka zuzena",
    "Add to your Nextcloud" : "Gehitu zure Nextcloud-era",
    "Media gallery for Nextcloud" : "Nextcloud multimedia galeria",
    "This share is password-protected" : "Elkarbanatutako hau pasahitzarekin babestuta dago",
    "The password is wrong. Try again." : "Pasahitza ez da egokia. Saiatu berriro.",
    "Cancel upload" : "Ezeztatu igoera",
    "Sort by name" : "Ordenatu izenaren arabera",
    "Sort by date" : "Ordenatu dataren arabera",
    "Album information" : "Albumaren informazioa",
    "File list" : "Fitxategi zerrenda",
    "Sorry, this file could not be found." : "Barkatu fitxategi hau ezin izan da aurkitu",
    "Reasons might be:" : "Arrazoiak hurrengoak litezke:",
    "the wrong file ID was provided" : "Fitxategiaren ID ezegokia eman da",
    "the file was removed" : "fitxategia ezabatua izan da",
    "the file is corrupt" : "fitxategia apurtua dago",
    "the encryption key is missing" : "enkriptazio gakoa falta da",
    "Here is the error message returned by the server: " : "Hona hemen zerbitzariak itzulitako errore mezua: ",
    "For more information, please contact your friendly Nextcloud administrator." : "Informazio gehiagorako, zure lagun Nextcloud administratzailearekin kontaktuan jar zaitez",
    "Sorry, but the server could not fulfill your request." : "Barkatu, baina zerbitzariak ezin du zure eskaera bete",
    "Possible reasons for the problem:" : "Arazoa sor dezaketen arrazoiak: ",
    "a conflicting app was installed" : "arazoak ematen duen app bat instalatu da",
    "a required component is missing or was disconnected" : "beharrezkoa den ezaugarri bat faltan edo deskonektatua dago",
    "the filesystem is not readable" : "fitxategi-sistema ezin da irakurri",
    "Sorry, this link doesn't seem to work anymore." : "Barkatu, ematen du lotura ez duela funtzionatzen.",
    "the item was removed" : "elementua ezabatua izan da",
    "the link has expired" : "lotura iraungi da",
    "sharing is disabled" : "elkarbanatzea ez dago gaituta",
    "For more information, please ask the person who has sent you this link." : "Informazio gehiagorako, eskatu lotura hau bidali dizun pertsonari",
    "Picture view" : "Irudi bistaratzea",
    "New" : "Berria"
},
"nplurals=2; plural=(n != 1);");
